/* FILE: ouput.cc                -*-Mode: c++-*-
 *
 * Output classes.  Each class providing output should embed an
 * instance of an output class for each output provided.
 *   Most of the real code is in the templated subclasses.  For
 * portability reasons, that code is in the header file, output.h.
 */

#include "director.h"
#include "output.h"

/* End includes */

Oxs_Output::Oxs_Output(const char* owner_name_,
		       const char* output_name_,
		       const char* output_type_,
		       const char* output_units_,
		       BOOL cache_support_,
		       Oxs_Director* director_)
  : director(director_),owner_name(owner_name_),
    output_name(output_name_),output_type(output_type_),
    output_units(output_units_),
    cache_support(cache_support_), cache_request_count(0)
{ // Registers with director_
  // Set director_ to NULL to disable automatic
  // registration/deregistration.
  if(director!=NULL) director->RegisterOutput(this);
}

Oxs_Output::~Oxs_Output()
{ // Deregisters
  if(director!=NULL) director->DeregisterOutput(this);
}

// Cache flag control
BOOL Oxs_Output::ForceCacheIncrement(INT4m incr)
{
  if(incr>0) cache_request_count+=incr;
  else if(incr<0) {
    UINT4m decr = -1*incr;
    if(cache_request_count < decr) cache_request_count = 0;
    else                           cache_request_count -= decr;
  }
  return 1;
}






