/* FILE: vectorfieldinit.h      -*-Mode: c++-*-
 *
 * Abstract Oxs_VectorFieldInit class, derives from Oxs_Ext, for
 * initializing Oxs_MeshValue<ThreeVector> objects.
 */

#include "vectorfieldinit.h"

/* End includes */

////////////////////////////////////////////////////////////////////////
// Oxs_VectorFieldInit (generic Oxs_Ext vector field) class

// Constructors
Oxs_VectorFieldInit::Oxs_VectorFieldInit
( const char* name,     // Child instance id
  Oxs_Director* newdtr  // App director
  ) : Oxs_Ext(name,newdtr)
{}

Oxs_VectorFieldInit::Oxs_VectorFieldInit
( const char* name,     // Child instance id
  Oxs_Director* newdtr, // App director
  Tcl_Interp* safe_interp, // Safe interpreter
  const char* argstr    // MIF block argument string
  ) : Oxs_Ext(name,newdtr,safe_interp,argstr)
{}

void
Oxs_VectorFieldInit::FillMeshValueOrthogonal
(const Oxs_Mesh* mesh,
 const Oxs_MeshValue<ThreeVector>& orth_array,
 Oxs_MeshValue<ThreeVector>& array) const
{
  FillMeshValue(mesh,array);
  if(!orth_array.CheckMesh(mesh) || !array.CheckMesh(mesh)) {
    string msg=
      string("Mesh size incompatibility detected in"
	     " Oxs_VectorFieldInit::FillMeshValueOrthogonal()"
	     " method of instance ")
      + string(InstanceName());
    throw Oxs_Ext::Error(msg.c_str());
  }
  UINT4m i,size=mesh->Size();
  const REAL8m eps_sq = 1e-28;
  for(i=0;i<size;i++) {
    REAL8m dot = orth_array[i]*array[i];
    REAL8m comp = eps_sq*orth_array[i].MagSq()*array[i].MagSq();
    if(dot*dot >= comp) {
      string msg=
	string("Orthogonality requirement failed in"
	       " Oxs_VectorFieldInit::FillMeshValueOrthogonal()"
	       " method of instance ")
	+ string(InstanceName());
      throw Oxs_Ext::Error(msg.c_str());
    }
  }
}
