/* FILE: fixedzeeman.h            -*-Mode: c++-*-
 *
 * Fixed (in time) Zeeman energy/field, derived from Oxs_Energy class.
 *
 */

#ifndef _OXS_FIXEDZEEMAN
#define _OXS_FIXEDZEEMAN

#include <memory>   // auto_ptr template

#include "oc.h"
#include "director.h"
#include "threevector.h"
#include "energy.h"
#include "simstate.h"
#include "mesh.h"
#include "meshvalue.h"
#include "vectorfieldinit.h"

/* End includes */

class Oxs_FixedZeeman:public Oxs_Energy {
private:
  mutable UINT4m mesh_id;
  auto_ptr<Oxs_VectorFieldInit> fixedfield_init;
  mutable Oxs_MeshValue<ThreeVector> fixedfield;
  /// fixedfield is a cached value filled by
  /// fixedfield_init when a change in mesh is
  /// detected.
public:
  virtual const char* ClassName() const; // ClassName() is
  /// automatically generated by the OXS_EXT_REGISTER macro.
  Oxs_FixedZeeman(const char* name,  // Child instance id
		  Oxs_Director* newdtr, // App director
		  Tcl_Interp* safe_interp, // Safe interpreter
		  const char* argstr);  // MIF input block parameters

  virtual ~Oxs_FixedZeeman() {}

  virtual void GetEnergyAndField(const Oxs_SimState& state,
                                 Oxs_MeshValue<REAL8m>& energy,
                                 Oxs_MeshValue<ThreeVector>& field
                                 ) const;
};


#endif // _OXS_FIXEDZEEMAN
