/* FILE: scriptatlas.h                 -*-Mode: c++-*-
 *
 * Script atlas class, derived from Oxs_Atlas class.
 *
 */

#ifndef _OXS_SCRIPTATLAS
#define _OXS_SCRIPTATLAS

#include <string>
#include <vector>

#include "ext.h"
#include "threevector.h"
#include "util.h"
#include "atlas.h"
/* End includes */

class Oxs_ScriptAtlas:public Oxs_Atlas {
private:
  Tcl_Interp* const safe_interp;
  Oxs_Box bounding_box;
  vector<string> region_name_list;
  vector<string> script_list;
#if (TCL_MAJOR_VERSION > 8 || (TCL_MAJOR_VERSION==8 && TCL_MINOR_VERSION>0))
  // If eval obj is available, then initialize obj command structures
  UINT4m objcmd_argc;
  Tcl_Obj** objcmd;
#endif // Tcl version check
public:
  virtual const char* ClassName() const; // ClassName() is
  /// automatically generated by the OXS_EXT_REGISTER macro.
  virtual BOOL Init() { return 1; }

  Oxs_ScriptAtlas(const char* name,
		  Oxs_Director* newdtr,
		  Tcl_Interp* safe_interp, // Safe interpreter
		  const char* argstr);   // MIF block argument string

  ~Oxs_ScriptAtlas();

  void GetWorldExtents(Oxs_Box &mybox) const {
    mybox = bounding_box;
  }

  INT4m GetRegionId(const ThreeVector& point) const;
  /// Returns the id number for the first region in
  /// "section_list" containing point.  The return
  /// value is -1 if the point is not contained in
  /// the atlas.

  INT4m GetRegionId(const string& name) const;
  /// Given a region id string (name), returns
  /// the corresponding region id index.  If
  /// "name" is not included in the atlas, then
  /// -1 is returned.

  INT4m GetRegionName(UINT4m id,string& name) const;
  /// Given an id number, fills in "name" with
  /// the corresponding region id string.  Returns
  /// 0 on success, 1 if id is invalid.

  UINT4m GetRegionCount() const {
    return UINT4m(region_name_list.size());
  }
  /// Valid RegionId numbers range from 0 to GetRegionCount -1,
  /// inclusive.

};

#endif // _OXS_SCRIPTATLAS
