/* FILE: autobuf.cc                   -*-Mode: c++-*-
 *
 * NOTICE: Please see the file ../../LICENSE
 *
 * Last modified on: $Date: 2001/03/31 04:17:15 $
 * Last modified by: $Author: donahue $
 */

/* Standard libraries */
#include <string.h>

/* Other classes and functions in this extension */
#include "autobuf.h"
#include "imports.h"

/* End includes */     

const size_t Oc_AutoBuf::reclaim_bound=1024;   // See Oc_AutoBuf::Dup()
const size_t Oc_AutoBuf::reclaim_proportion=4;

void Oc_AutoBuf::Dup(const char* const_str)
{
  size_t needsize=strlen(const_str)+1;
  if(needsize>bufsize || 
     (bufsize>reclaim_bound && bufsize/reclaim_proportion>needsize)) {
    if(bufsize>0) delete[] str;
    bufsize=needsize;
    str=new char[bufsize];
    if(str==0) panic((char *)"No memory in Oc_AutoBuf::Dup");
  }
  strcpy(str,const_str);
}
 
Oc_AutoBuf::Oc_AutoBuf()
{
  bufsize=0;
  str=NULL; // Safety
  Dup("");
}
 
Oc_AutoBuf::Oc_AutoBuf(const char* const_str)
{
  bufsize=0;
  str=NULL; // Safety
  Dup(const_str);
}
 
char* Oc_AutoBuf::operator()(const char* const_str)
{
  Dup(const_str);
  return str;
}
 
Oc_AutoBuf::~Oc_AutoBuf()
{
  delete[] str;
}

void Oc_AutoBuf::SetLength(size_t newlength)
{ // bufsize = length + 1
  size_t newsize=newlength+1;
  if(newsize!=bufsize) {
    char* tempstr = new char[newsize];
    if(tempstr==0)
      panic((char *)"Insufficient memory in Oc_AutoBuf::SetLength");
    if(bufsize>0) {
      size_t minsize = ( bufsize<newsize ? bufsize : newsize );
      strncpy(tempstr,str,minsize-1);
      tempstr[newsize-1]='\0'; // Safety
      delete[] str;
    }
    str = tempstr;
    bufsize = newsize;
  }
}
